==> ejc-cost-api-3.0.0-20201209.075504-6-sources.jar: com/ejianc/business/cost/vo/SubjectVO.java <==
package com.ejianc.business.cost.vo;

import com.ejianc.business.cost.utils.ITreeNodeB;
import com.ejianc.framework.skeleton.template.BaseVO;

import java.util.ArrayList;
import java.util.List;


/**
 * 成本设置科目明细
 * 
 * @author generator
 * 
 */
public class SubjectVO extends BaseVO implements ITreeNodeB {
    private static final long serialVersionUID = 1L;
    
    private java.lang.Long settingId; // 主表主键ID
    private java.lang.String subjectCode; // 科目编码
    private java.lang.String subjectName; // 科目名称
    private java.lang.String memo; // 描述
    private java.lang.String createUserName; // 创建人名称
    private java.lang.String detailIndex; // 序号  1   1.1
    private java.lang.Long parentId; // parent_id    一级默认  999  子集赋值上级的 tid
    private java.lang.Integer leafFlag; // 是否末级  true/false
    private java.lang.Long tid; // 树形主键    前端生成不重复标识

    private java.lang.String status; // 启用状态0-启用1-停用

    private List<ITreeNodeB> children; //子集数据

    public String getStatus() {
        return status;
    }

    public void setStatus(String status) {
        this.status = status;
    }

    /**
     * 主表主键ID
     */
    public java.lang.Long getSettingId() {
        return settingId;
    }

    /**
     * 主表主键ID
     */
    public void setSettingId(java.lang.Long settingId) {
        this.settingId = settingId;
    }
    /**
     * 科目编码
     */
    public java.lang.String getSubjectCode() {
        return subjectCode;
    }

    /**
     * 科目编码
     */
    public void setSubjectCode(java.lang.String subjectCode) {
        this.subjectCode = subjectCode;
    }
    /**
     * 科目名称
     */
    public java.lang.String getSubjectName() {
        return subjectName;
    }

    /**
     * 科目名称
     */
    public void setSubjectName(java.lang.String subjectName) {
        this.subjectName = subjectName;
    }
    /**
     * 描述
     */
    public java.lang.String getMemo() {
        return memo;
    }

    /**
     * 描述
     */
    public void setMemo(java.lang.String memo) {
        this.memo = memo;
    }
    /**
     * 创建人名称
     */
    public java.lang.String getCreateUserName() {
        return createUserName;
    }

    /**
     * 创建人名称
     */
    public void setCreateUserName(java.lang.String createUserName) {
        this.createUserName = createUserName;
    }
    /**
     * 序号
     */
    public java.lang.String getDetailIndex() {
        return detailIndex;
    }

    /**
     * 序号
     */
    public void setDetailIndex(java.lang.String detailIndex) {
        this.detailIndex = detailIndex;
    }
    /**
     * parent_id
     */
    public java.lang.Long getParentId() {
        return parentId;
    }

    /**
     * parent_id
     */
    public void setParentId(java.lang.Long parentId) {
        this.parentId = parentId;
    }
    /**
     * 是否末级
     */
    public java.lang.Integer getLeafFlag() {
        return leafFlag;
    }

    /**
     * 是否末级
     */
    public void setLeafFlag(java.lang.Integer leafFlag) {
        this.leafFlag = leafFlag;
    }
    /**
     * 树形主键
     */
    public java.lang.Long getTid() {
        return tid;
    }

    /**
     * 树形主键
     */
    public void setTid(java.lang.Long tid) {
        this.tid = tid;
    }

    @Override
    public Long getNodeID() {
        return getTid();
    }

    @Override
    public Long getParentID() {
        return parentId;
    }

    public List<ITreeNodeB> getChildren() {
        if (children == null) {
            children = new ArrayList<>();
        }
        return children;

    }
    
}

==> ejc-cost-api-3.0.0-20210310.062015-72-sources.jar: com/ejianc/business/cost/vo/SubjectVO.java <==
package com.ejianc.business.cost.vo;

import com.ejianc.business.cost.utils.ITreeNodeB;
import com.ejianc.framework.skeleton.template.BaseVO;

import java.util.ArrayList;
import java.util.List;


/**
 * 成本设置科目明细
 * 
 * @author generator
 * 
 */
public class SubjectVO extends BaseVO implements ITreeNodeB {
    private static final long serialVersionUID = 1L;
    
    private java.lang.Long settingId; // 主表主键ID
    private java.lang.String subjectCode; // 科目编码
    private java.lang.String subjectName; // 科目名称
    private java.lang.String memo; // 描述
    private java.lang.String createUserName; // 创建人名称
    private java.lang.String detailIndex; // 序号  1   1.1
    private java.lang.Long parentId; // parent_id    一级默认  999  子集赋值上级的 tid
    private Boolean leafFlag; // 是否末级  true/false
    private java.lang.Long tid; // 树形主键    前端生成不重复标识

    private java.lang.String status; // 启用状态0-启用1-停用

    private List<ITreeNodeB> children; //子集数据

    public String getStatus() {
        return status;
    }

    public void setStatus(String status) {
        this.status = status;
    }

    /**
     * 主表主键ID
     */
    public java.lang.Long getSettingId() {
        return settingId;
    }

    /**
     * 主表主键ID
     */
    public void setSettingId(java.lang.Long settingId) {
        this.settingId = settingId;
    }
    /**
     * 科目编码
     */
    public java.lang.String getSubjectCode() {
        return subjectCode;
    }

    /**
     * 科目编码
     */
    public void setSubjectCode(java.lang.String subjectCode) {
        this.subjectCode = subjectCode;
    }
    /**
     * 科目名称
     */
    public java.lang.String getSubjectName() {
        return subjectName;
    }

    /**
     * 科目名称
     */
    public void setSubjectName(java.lang.String subjectName) {
        this.subjectName = subjectName;
    }
    /**
     * 描述
     */
    public java.lang.String getMemo() {
        return memo;
    }

    /**
     * 描述
     */
    public void setMemo(java.lang.String memo) {
        this.memo = memo;
    }
    /**
     * 创建人名称
     */
    public java.lang.String getCreateUserName() {
        return createUserName;
    }

    /**
     * 创建人名称
     */
    public void setCreateUserName(java.lang.String createUserName) {
        this.createUserName = createUserName;
    }
    /**
     * 序号
     */
    public java.lang.String getDetailIndex() {
        return detailIndex;
    }

    /**
     * 序号
     */
    public void setDetailIndex(java.lang.String detailIndex) {
        this.detailIndex = detailIndex;
    }
    /**
     * parent_id
     */
    public java.lang.Long getParentId() {
        return parentId;
    }

    /**
     * parent_id
     */
    public void setParentId(java.lang.Long parentId) {
        this.parentId = parentId;
    }
    /**
     * 是否末级
     */
    public Boolean getLeafFlag() {
        return leafFlag;
    }

    public void setLeafFlag(Boolean leafFlag) {
        this.leafFlag = leafFlag;
    }

    /**
     * 树形主键
     */
    public java.lang.Long getTid() {
        return tid;
    }

    /**
     * 树形主键
     */
    public void setTid(java.lang.Long tid) {
        this.tid = tid;
    }

    @Override
    public Long getNodeID() {
        return getTid();
    }

    @Override
    public Long getParentID() {
        return parentId;
    }

    public List<ITreeNodeB> getChildren() {
        if (children == null) {
            children = new ArrayList<>();
        }
        return children;

    }
    
}
